@@ -381,31 +381,137 @@ EOX
                  @configuration.to_xml)
   end
 
-  def test_define_milter_again
-    @loader.define_milter("milter1") do |milter|
-      milter.description = "description"
-      milter.enabled = true
-    end
-    assert_equal([["milter1", true, "description"]],
-                 @configuration.eggs.collect do |egg|
-                   [egg.name, egg.enabled?, egg.description]
-                 end)
+  class TestDefineMilter < self
+    def test_again
+      @loader.define_milter("milter1") do |milter|
+        milter.description = "description"
+        milter.enabled = true
+      end
+      assert_equal([["milter1", true, "description"]],
+                   @configuration.eggs.collect do |egg|
+                     [egg.name, egg.enabled?, egg.description]
+                   end)
 
-    @loader.define_milter("milter1") do |milter|
-    end
-    assert_equal([["milter1", true, "description"]],
-                 @configuration.eggs.collect do |egg|
-                   [egg.name, egg.enabled?, egg.description]
-                 end)
+      @loader.define_milter("milter1") do |milter|
+      end
+      assert_equal([["milter1", true, "description"]],
+                   @configuration.eggs.collect do |egg|
+                     [egg.name, egg.enabled?, egg.description]
+                   end)
 
-    @loader.define_milter("milter1") do |milter|
-      milter.description = "new description"
-      milter.enabled = false
+      @loader.define_milter("milter1") do |milter|
+        milter.description = "new description"
+        milter.enabled = false
+      end
+      assert_equal([["milter1", false, "new description"]],
+                   @configuration.eggs.collect do |egg|
+                     [egg.name, egg.enabled?, egg.description]
+                   end)
+    end
+
+    def test_set_applicable_conditions
+      @loader.define_applicable_condition("S25R") do |condition|
+        condition.description = "Selective SMTP Rejection."
+      end
+      @loader.define_applicable_condition("Remote Network") do |condition|
+        condition.description = "Only works for remote network."
+      end
+
+      @loader.define_milter("milter1") do |milter|
+        milter.applicable_conditions = ["S25R", "Remote Network"]
+      end
+      assert_equal([["milter1", ["S25R", "Remote Network"]]],
+                   @configuration.eggs.collect do |egg|
+                     [egg.name,
+                      egg.applicable_conditions.collect {|cond| cond.name}]
+                   end)
+
+      @loader.define_milter("milter2") do |milter|
+        milter.applicable_conditions = ["S25R", "Remote Network"]
+        milter.applicable_conditions = ["S25R"]
+      end
+      assert_equal([["milter1", ["S25R", "Remote Network"]],
+                    ["milter2", ["S25R"]]],
+                   @configuration.eggs.collect do |egg|
+                     [egg.name,
+                      egg.applicable_conditions.collect {|cond| cond.name}]
+                   end)
+    end
+
+    def test_add_applicable_condition
+      @loader.define_applicable_condition("S25R") do |condition|
+        condition.description = "Selective SMTP Rejection."
+      end
+      @loader.define_applicable_condition("Remote Network") do |condition|
+        condition.description = "Only works for remote network."
+      end
+
+      @loader.define_milter("milter1") do |milter|
+        milter.applicable_conditions = ["S25R"]
+        milter.applicable_conditions += ["Remote Network"]
+      end
+      assert_equal([["milter1", ["S25R", "Remote Network"]]],
+                   @configuration.eggs.collect do |egg|
+                     [egg.name,
+                      egg.applicable_conditions.collect {|cond| cond.name}]
+                   end)
+    end
+
+    class TestFallbackStatus < self
+      def test_valid
+        @loader.define_milter("milter") do |milter|
+          assert_equal("accept", milter.fallback_status)
+          milter.fallback_status = "temporary_failure"
+          assert_equal("temporary-failure", milter.fallback_status)
+        end
+      end
+
+      def test_invalid
+        @loader.define_milter("milter") do |milter|
+          assert_raise(Milter::Manager::ConfigurationLoader::InvalidValue) do
+            milter.fallback_status = "default"
+          end
+        end
+      end
+    end
+
+    class TestCommandOptions < self
+      def test_string_style
+        command_options = "--connection-spec=inet:20001 --daemon"
+        @loader.define_milter("milter") do |milter|
+          milter.command = "milter-test-client"
+          milter.command_options = command_options
+        end
+        egg = @configuration.eggs.first
+        assert_equal(command_options, egg.command_options)
+      end
+
+      class TestArrayStyle < self
+        def test_normal_characters
+          command_options = [
+            "--verbose",
+            "--daemon",
+          ]
+          assert_command_options(command_options)
+        end
+
+        data("=",     ["--connection-spec=inet:20001"])
+        data("space", ["--n-workers 4"])
+        def test_shell_special_characters(command_options)
+          assert_command_options(command_options)
+        end
+
+        private
+        def assert_command_options(command_options)
+          @loader.define_milter("milter") do |milter|
+            milter.command = "milter-test-client"
+            milter.command_options = command_options
+          end
+          egg = @configuration.eggs.first
+          assert_equal(command_options, Shellwords.split(egg.command_options))
+        end
+      end
     end
-    assert_equal([["milter1", false, "new description"]],
-                 @configuration.eggs.collect do |egg|
-                   [egg.name, egg.enabled?, egg.description]
-                 end)
   end
 
   def test_remove_milter
@@ -438,70 +544,6 @@ EOX
                  end)
   end
 
-  def test_define_milter_set_applicable_conditions
-    @loader.define_applicable_condition("S25R") do |condition|
-      condition.description = "Selective SMTP Rejection."
-    end
-    @loader.define_applicable_condition("Remote Network") do |condition|
-      condition.description = "Only works for remote network."
-    end
-
-    @loader.define_milter("milter1") do |milter|
-      milter.applicable_conditions = ["S25R", "Remote Network"]
-    end
-    assert_equal([["milter1", ["S25R", "Remote Network"]]],
-                 @configuration.eggs.collect do |egg|
-                   [egg.name,
-                    egg.applicable_conditions.collect {|cond| cond.name}]
-                 end)
-
-    @loader.define_milter("milter2") do |milter|
-      milter.applicable_conditions = ["S25R", "Remote Network"]
-      milter.applicable_conditions = ["S25R"]
-    end
-    assert_equal([["milter1", ["S25R", "Remote Network"]],
-                  ["milter2", ["S25R"]]],
-                 @configuration.eggs.collect do |egg|
-                   [egg.name,
-                    egg.applicable_conditions.collect {|cond| cond.name}]
-                 end)
-  end
-
-  def test_define_milter_add_applicable_condition
-    @loader.define_applicable_condition("S25R") do |condition|
-      condition.description = "Selective SMTP Rejection."
-    end
-    @loader.define_applicable_condition("Remote Network") do |condition|
-      condition.description = "Only works for remote network."
-    end
-
-    @loader.define_milter("milter1") do |milter|
-      milter.applicable_conditions = ["S25R"]
-      milter.applicable_conditions += ["Remote Network"]
-    end
-    assert_equal([["milter1", ["S25R", "Remote Network"]]],
-                 @configuration.eggs.collect do |egg|
-                   [egg.name,
-                    egg.applicable_conditions.collect {|cond| cond.name}]
-                 end)
-  end
-
-  def test_define_milter_fallback_status
-    @loader.define_milter("milter") do |milter|
-      assert_equal("accept", milter.fallback_status)
-      milter.fallback_status = "temporary_failure"
-      assert_equal("temporary-failure", milter.fallback_status)
-    end
-  end
-
-  def test_define_milter_invalid_fallback_status
-    @loader.define_milter("milter") do |milter|
-      assert_raise(Milter::Manager::ConfigurationLoader::InvalidValue) do
-        milter.fallback_status = "default"
-      end
-    end
-  end
-
   def test_define_applicable_condition_again
     @loader.define_applicable_condition("S25R") do |condition|
       condition.description = "Selective SMTP Rejection."
