@@ -959,6 +959,68 @@ void                 milter_client_context_set_packet_buffer_size
 guint                milter_client_context_get_packet_buffer_size
                                                        (MilterClientContext *context);
 
+
+/**
+ * milter_client_context_set_mail_transaction_shelf_value:
+ * @context: a %MilterClientContext.
+ * @key: a string
+ * @value: a string
+ *
+ * Sets the string for the mail_transaction_shelf.
+ *
+ */
+void                 milter_client_context_set_mail_transaction_shelf_value
+                                                       (MilterClientContext *context,
+                                                        const gchar *key,
+                                                        const gchar *value);
+
+/**
+ * milter_client_context_get_mail_transaction_shelf_value:
+ * @context: a %MilterClientContext.
+ * @key: a key
+ *
+ * Gets the string for the mail_transaction_shelf.
+ *
+ * Returns: the string for the mail_transaction_shelf.
+ */
+const gchar         *milter_client_context_get_mail_transaction_shelf_value
+                                                       (MilterClientContext *context,
+                                                        const gchar *key);
+
+/**
+ * milter_client_context_get_mail_transaction_shelf:
+ * @context: a %MilterClientContext.
+ *
+ * Gets the mail_transaction_shelf.
+ * This is a mail-transaction scope storage.
+ *
+ * Returns: the GHashTable for the context.
+ */
+GHashTable          *milter_client_context_get_mail_transaction_shelf
+                                                       (MilterClientContext *context);
+/**
+ * milter_client_context_clear_mail_transaction_shelf:
+ * @context: a %MilterClientContext.
+ *
+ * Remove all keys and values from mail_transaction_shelf.
+ *
+ */
+void                 milter_client_context_clear_mail_transaction_shelf
+                                                       (MilterClientContext *context);
+
+/**
+ * milter_client_context_mail_transaction_shelf_foreach:
+ * @context: a %MilterClientContext.
+ * @func: the function to call for each key/value pair
+ * @user_data: user data to pass to the function
+ *
+ * A wrapper for g_hash_table_foreach().
+ */
+void                 milter_client_context_mail_transaction_shelf_foreach
+                                                       (MilterClientContext *context,
+                                                        GHFunc func,
+                                                        gpointer user_data);
+
 G_END_DECLS
 
 #endif /* __MILTER_CLIENT_CONTEXT_H__ */
