@@ -498,6 +498,7 @@ guint
 milter_utils_flags_from_string (GType        flags_type,
                                 const gchar *flags_string,
                                 guint        base_flags,
+                                guint        default_flags,
                                 GError     **error)
 {
     gchar **split_names, **names;
@@ -559,10 +560,17 @@ milter_utils_flags_from_string (GType        flags_type,
 
             value = g_flags_get_value_by_nick(flags_class, name);
             if (value) {
+                guint current_flags;
+
+                current_flags = value->value;
+                if (current_flags == 0 && g_str_equal(name, "default")) {
+                    current_flags = default_flags;
+                }
+
                 if (local_append) {
-                    flags |= value->value;
+                    flags |= current_flags;
                 } else {
-                    flags &= ~(value->value);
+                    flags &= ~current_flags;
                 }
             } else {
                 if (!unknown_strings)
@@ -759,6 +767,7 @@ milter_utils_guess_console_color_usability (void)
     term = g_getenv("TERM");
     if (term && (g_str_has_suffix(term, "term") ||
                  g_str_has_suffix(term, "term-color") ||
+                 g_str_has_suffix(term, "term-256color") ||
                  g_str_equal(term, "screen") ||
                  g_str_equal(term, "linux")))
         return TRUE;
@@ -913,32 +922,6 @@ milter_utils_parse_file_mode (const gchar *string,
     return success;
 }
 
-#if GLIB_CHECK_VERSION(2, 14, 0)
-GList *
-milter_utils_hash_table_get_keys (GHashTable *table)
-{
-    return g_hash_table_get_keys(table);
-}
-#else
-static void
-collect_key (gpointer key, gpointer value, gpointer user_data)
-{
-    GList **keys = (GList **)user_data;
-
-    *keys = g_list_prepend(*keys, key);
-}
-
-GList *
-milter_utils_hash_table_get_keys (GHashTable *table)
-{
-    GList *keys = NULL;
-
-    g_hash_table_foreach(table, collect_key, &keys);
-
-    return keys;
-}
-#endif
-
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
