@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2010  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -111,6 +111,7 @@ typedef enum
 
 /**
  * MilterServerContextState:
+ * @MILTER_SERVER_CONTEXT_STATE_INVALID: Invalid state.
  * @MILTER_SERVER_CONTEXT_STATE_START: Just started.
  * @MILTER_SERVER_CONTEXT_STATE_DEFINE_MACRO: Sent macro definition.
  * @MILTER_SERVER_CONTEXT_STATE_NEGOTIATE: Negotiating.
@@ -137,6 +138,7 @@ typedef enum
  */
 typedef enum
 {
+    MILTER_SERVER_CONTEXT_STATE_INVALID,
     MILTER_SERVER_CONTEXT_STATE_START,
     MILTER_SERVER_CONTEXT_STATE_DEFINE_MACRO,
     MILTER_SERVER_CONTEXT_STATE_NEGOTIATE,
@@ -203,6 +205,9 @@ struct _MilterServerContextClass
 
     void (*message_processed)   (MilterServerContext *context,
                                  MilterMessageResult *result);
+
+    void (*state_transited)     (MilterServerContext *context,
+                                 MilterServerContextState state);
 };
 
 GQuark               milter_server_context_error_quark (void);
@@ -712,6 +717,20 @@ void                 milter_server_context_set_message_result
 gboolean             milter_server_context_need_reply (MilterServerContext *context,
                                                        MilterServerContextState state);
 
+/**
+ * milter_server_context_has_accepted_recipient:
+ * @context: a %MilterServerContext.
+ *
+ * Returns %TRUE if the context has one or more accepted
+ * recipients. If the context doesn't know about recipients,
+ * it always returns %FALSE.
+ *
+ * Returns: %TRUE if @context has one or more accepted
+ * recipients, %FALSE otherwise.
+ */
+gboolean             milter_server_context_has_accepted_recipient
+                                                      (MilterServerContext *context);
+
 G_END_DECLS
 
 #endif /* __MILTER_SERVER_CONTEXT_H__ */
