@@ -734,6 +734,10 @@ setup_process_launcher (MilterManagerChildren *children)
     GIOChannel *read_channel, *write_channel;
     MilterReader *reader;
     MilterWriter *writer;
+    GError *error = NULL;
+
+    if (MILTER_IS_LIBEV_EVENT_LOOP(loop))
+        cut_omit("MilterLibevEventLoop doesn't support GCutStringIOChannel.");
 
     launcher = milter_manager_process_launcher_new();
     milter_agent_set_event_loop(MILTER_AGENT(launcher), loop);
@@ -753,7 +757,8 @@ setup_process_launcher (MilterManagerChildren *children)
     g_io_channel_unref(read_channel);
     g_io_channel_unref(write_channel);
 
-    milter_agent_start(MILTER_AGENT(launcher), NULL);
+    milter_agent_start(MILTER_AGENT(launcher), &error);
+    gcut_assert_error(error);
 }
 
 static void
@@ -1734,8 +1739,6 @@ data_important_status (void)
                  test_data(BODY, SKIP, REJECT), g_free,
                  "body - skip - discard",
                  test_data(BODY, SKIP, DISCARD), g_free,
-                 "body - accept - skip",
-                 test_data(BODY, ACCEPT, SKIP), g_free,
                  NULL);
     add_data("end of message", END_OF_MESSAGE);
 
@@ -2007,6 +2010,9 @@ test_writing_timeout (void)
     MilterWriter *writer;
     MilterManagerChild *child;
 
+    if (MILTER_IS_LIBEV_EVENT_LOOP(loop))
+        cut_omit("MilterLibevEventLoop doesn't support GCutStringIOChannel.");
+
     cut_trace(test_negotiate());
 
     disconnect_default_handler();
