@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2013  Kouhei Sutou <kou@clear-code.com>
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,6 +40,7 @@
 
 #include <milter/server.h>
 #include <milter/core.h>
+#include <milter/core/milter-glib-compatible.h>
 
 #define DEFAULT_NEGOTIATE_VERSION 6
 
@@ -1176,33 +1177,26 @@ extract_path_from_mail_address (const gchar *mail_address, GError **error)
 }
 
 static gboolean
-parse_header (const gchar *line, GList **recipient_list, GError **error)
+parse_header (const gchar *name, const gchar *value,
+              GList **recipient_list, GError **error)
 {
-    gchar **strings;
-
-    if (g_str_has_prefix(line, "From: ")) {
+    if (strcmp(name, "From") == 0) {
         gchar *reverse_path;
 
-        reverse_path = extract_path_from_mail_address(line + strlen("From :"),
-                                                      error);
+        reverse_path = extract_path_from_mail_address(value, error);
         if (!reverse_path)
             return FALSE;
         set_envelope_from(reverse_path);
         g_free(reverse_path);
-    } else if (g_str_has_prefix(line, "To: ")) {
+    } else if (strcmp(name, "To") == 0) {
         gchar *forward_path;
 
-        forward_path = extract_path_from_mail_address(line + strlen("To: "),
-                                                      error);
+        forward_path = extract_path_from_mail_address(value, error);
         if (!forward_path)
             return FALSE;
         *recipient_list = g_list_append(*recipient_list, forward_path);
     }
 
-    strings = g_strsplit(line, ":", 2);
-    milter_headers_append_header(option_headers, strings[0], g_strchug(strings[1]));
-    g_strfreev(strings);
-
     return TRUE;
 }
 
@@ -1218,15 +1212,28 @@ is_header (const gchar *line)
 }
 
 static void
-append_header_value (const gchar *value, const gchar *new_line)
+append_header (MilterHeaders *headers, const char *header_line)
+{
+    gchar **header_and_value;
+
+    header_and_value = g_strsplit(header_line, ":", 2);
+    milter_headers_append_header(headers,
+                                 header_and_value[0],
+                                 g_strchug(header_and_value[1]));
+    g_strfreev(header_and_value);
+
+}
+
+static void
+append_header_value (MilterHeaders *headers, const gchar *value,
+                     const gchar *new_line)
 {
     MilterHeader *last_header;
     guint last;
     gchar *old_value;
 
-    last = milter_headers_length(option_headers);
-    last_header = milter_headers_get_nth_header(option_headers,
-                                                last);
+    last = milter_headers_length(headers);
+    last_header = milter_headers_get_nth_header(headers, last);
 
     old_value = last_header->value;
     last_header->value = g_strdup_printf("%s%s%s",
@@ -1237,19 +1244,11 @@ append_header_value (const gchar *value, const gchar *new_line)
 }
 
 static gboolean
-parse_mail_contents (const gchar *contents, GError **error)
+parse_mail_contents_header_part_collect_headers (gchar ***lines_,
+                                                 MilterHeaders *headers,
+                                                 GError **error)
 {
-    gchar **lines, **first_lines;
-    GList *recipient_list = NULL;
-    GString *body_string;
-    GPtrArray *chunks;
-
-    lines = g_strsplit(contents, "\n", -1);
-    first_lines = lines;
-
-    /* Ignore mbox separation 'From ' mark. */
-    if (g_str_has_prefix(*lines, "From "))
-        lines++;
+    gchar **lines = *lines_;
 
     for (; *lines; lines++) {
         gchar *line = *lines;
@@ -1266,10 +1265,7 @@ parse_mail_contents (const gchar *contents, GError **error)
             lines++;
             break;
         } else if (is_header(line)) {
-            if (!parse_header(line, &recipient_list, error)) {
-                g_strfreev(first_lines);
-                return FALSE;
-            }
+            append_header(headers, line);
         } else if (g_ascii_isspace(line[0])) {
             const gchar *new_line;
             if (have_cr) {
@@ -1277,17 +1273,90 @@ parse_mail_contents (const gchar *contents, GError **error)
             } else {
                 new_line = "\n";
             }
-            append_header_value(line, new_line);
+            append_header_value(headers, line, new_line);
         } else {
             g_set_error(error,
                         MILTER_TEST_SERVER_ERROR,
                         MILTER_TEST_SERVER_ERROR_INVALID_HEADER,
                         "invalid header: <%s>",
                         line);
-            g_strfreev(first_lines);
             return FALSE;
         }
     }
+    *lines_ = lines;
+
+    return TRUE;
+}
+
+static gboolean
+parse_mail_contents_header_part_parse_headers (MilterHeaders *headers,
+                                               GError **error)
+{
+    const GList *header_list;
+    GList *recipient_list = NULL;
+
+    header_list = milter_headers_get_list(headers);
+    for (; header_list; header_list = g_list_next(header_list)) {
+        MilterHeader *header = header_list->data;
+        if (!parse_header(header->name, header->value,
+                          &recipient_list, error)) {
+            return FALSE;
+        }
+    }
+
+    if (recipient_list) {
+        gint i, length;
+        GList *node;
+
+        length = g_list_length(recipient_list);
+        recipients = g_new0(gchar *, length + 1);
+        for (i = 0, node = recipient_list; node; i++, node = g_list_next(node)) {
+            recipients[i] = node->data;
+        }
+        recipients[length] = NULL;
+        g_list_free(recipient_list);
+    }
+
+    return TRUE;
+}
+
+static gboolean
+parse_mail_contents_header_part (gchar ***lines_, GError **error)
+{
+    MilterHeaders *headers;
+    const GList *header_list;
+
+    headers = milter_headers_new();
+    if (!parse_mail_contents_header_part_collect_headers(lines_,
+                                                         headers,
+                                                         error)) {
+        g_object_unref(headers);
+        return FALSE;
+    }
+
+    if (!parse_mail_contents_header_part_parse_headers(headers, error)) {
+        g_object_unref(headers);
+        return FALSE;
+    }
+
+    header_list = milter_headers_get_list(headers);
+    for (; header_list; header_list = g_list_next(header_list)) {
+        MilterHeader *header = header_list->data;
+        milter_headers_append_header(option_headers,
+                                     header->name, header->value);
+    }
+
+    g_object_unref(headers);
+
+    return TRUE;
+}
+
+static gboolean
+parse_mail_contents_body_part (gchar ***lines_, GError **error)
+{
+    gchar **lines = *lines_;
+    GString *body_string;
+    GPtrArray *chunks;
 
     chunks = g_ptr_array_new();
     body_string = g_string_new(NULL);
@@ -1305,6 +1374,8 @@ parse_mail_contents (const gchar *contents, GError **error)
         g_string_append(body_string, line);
         g_string_append(body_string, "\n");
     }
+    *lines_ = lines;
+
     if (body_string->len > 0) {
         gsize last_new_line_length;
 
@@ -1320,17 +1391,29 @@ parse_mail_contents (const gchar *contents, GError **error)
     g_ptr_array_add(chunks, NULL);
     body_chunks = (gchar **)g_ptr_array_free(chunks, FALSE);
 
-    if (recipient_list) {
-        gint i, length;
-        GList *node;
+    return TRUE;
+}
 
-        length = g_list_length(recipient_list);
-        recipients = g_new0(gchar *, length + 1);
-        for (i = 0, node = recipient_list; node; i++, node = g_list_next(node)) {
-            recipients[i] = node->data;
-        }
-        recipients[length] = NULL;
-        g_list_free(recipient_list);
+static gboolean
+parse_mail_contents (const gchar *contents, GError **error)
+{
+    gchar **lines, **first_lines;
+
+    lines = g_strsplit(contents, "\n", -1);
+    first_lines = lines;
+
+    /* Ignore mbox separation 'From ' mark. */
+    if (g_str_has_prefix(*lines, "From "))
+        lines++;
+
+    if (!parse_mail_contents_header_part(&lines, error)) {
+        g_strfreev(first_lines);
+        return FALSE;
+    }
+
+    if (!parse_mail_contents_body_part(&lines, error)) {
+        g_strfreev(first_lines);
+        return FALSE;
     }
 
     g_strfreev(first_lines);
@@ -2257,7 +2340,10 @@ main (int argc, char *argv[])
         process_data = g_new0(ProcessData, n_threads);
         for (i = 0; i < n_threads; i++) {
             init_process_data(&process_data[i]);
-            threads[i] = g_thread_create(test_server_thread, &process_data[i], TRUE, NULL);
+            threads[i] = g_thread_try_new("test_server_thread",
+                                          test_server_thread,
+                                          &process_data[i],
+                                          NULL);
         }
 
         for (i = 0; i < n_threads; i++) {
@@ -2275,12 +2361,13 @@ main (int argc, char *argv[])
     }
 
 
-    milter_server_quit();
-    milter_quit();
     g_option_context_free(option_context);
     free_option_values();
 
-    exit(success ? EXIT_SUCCESS : EXIT_FAILURE);
+    milter_server_quit();
+    milter_quit();
+
+    return success ? EXIT_SUCCESS : EXIT_FAILURE;
 }
 
 /*
